@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 14.3 Debian package creator
-# Release 2018-05-10
+# DaVinci Resolve 15.0 Debian package creator
+# Release 2018-08-13
 # By Daniel Tufvesson
 #
 
@@ -97,8 +97,8 @@ extract_zip() {
 }
 
 # Setup variables
-RESOLVE_VERSION=14.3
-DEB_STEPPING=2
+RESOLVE_VERSION=15.0
+DEB_STEPPING=1
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -148,6 +148,7 @@ create_directory ${RESOLVE_BASE_DIR}/logs
 create_directory ${RESOLVE_BASE_DIR}/scripts
 create_directory ${RESOLVE_BASE_DIR}/.LUT
 create_directory ${RESOLVE_BASE_DIR}/.license
+create_directory ${RESOLVE_BASE_DIR}/DolbyVision
 create_directory ${RESOLVE_BASE_DIR}/Fairlight
 create_directory ${RESOLVE_BASE_DIR}/Media
 create_directory ${RESOLVE_BASE_DIR}/"Resolve Disk Database"
@@ -185,10 +186,12 @@ copy_object ${UNPACK_DIR}/rsf/log-conf.xml ${RESOLVE_BASE_DIR}/configs/log-conf.
 extract_tgz ${UNPACK_DIR}/panels/libusb-1.0.tgz ${RESOLVE_BASE_DIR}/bin
 extract_tgz ${UNPACK_DIR}/panels/dvpanel-framework-linux-x86_64.tgz ${RESOLVE_BASE_DIR}/bin
 extract_tgz ${UNPACK_DIR}/panels/dvpanel-utility-linux-x86_64.tgz ${RESOLVE_BASE_DIR}
+extract_zip ${UNPACK_DIR}/rsf/fusion_presets.zip ${RESOLVE_BASE_DIR}
 extract_inplace_gz ${RESOLVE_BASE_DIR}/LUT/trim_lut0.dpx.gz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/aaf_runtime_libs_x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/easydcp-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/fairlight-lib-linux-x86_64.tgz
+extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/fusion-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/ffmpeg-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/graphviz-rt-linux-x86_64.tgz
 extract_inplace_tgz ${RESOLVE_BASE_DIR}/libs/log4cxx_runtime_libs_x64.tgz
@@ -243,6 +246,7 @@ test -e /opt/resolve/configs/config.dat || cp /opt/resolve/configs/config.dat-pk
 test -e /opt/resolve/configs/log-conf.xml || cp /opt/resolve/configs/log-conf.xml-pkg-default /opt/resolve/configs/log-conf.xml
 chmod -R a+rw /opt/resolve/configs
 chmod -R a+rw /opt/resolve/Media
+chmod -R a+rw /opt/resolve/DolbyVision
 chmod -R a+rw /opt/resolve/Fairlight
 chmod -R a+rw /opt/resolve/easyDCP
 chmod -R a+rw /opt/resolve/Developer
